@@ -88,9 +88,9 @@ class TextEncoder(BaseModel):
         super().__init__(args, layernorm_epsilon=layernorm_epsilon, activation_func=activation_func)
         self.add_mixin('text_enc', TextMixin(args.hidden_size, args.projection_dim))
 
-    @classmethod
-    def add_model_specific_args(cls, parser):
-        return super().add_model_specific_args(parser)
+    # @classmethod
+    # def add_model_specific_args(cls, parser):
+    #     return super().add_model_specific_args(parser)
 
 import argparse
 
@@ -99,7 +99,7 @@ class CLIP(nn.Module):
         super().__init__()
         self.image_encoder = ImageEncoder(args, layernorm_epsilon=layernorm_epsilon)
         text_args = argparse.Namespace(**vars(args))
-        override_attrs = ['vocab_size', 'num_layers', 'hidden_size', 'num_attention_heads', 'layernorm_order'
+        override_attrs = ['vocab_size', 'num_layers', 'hidden_size', 'num_attention_heads', 'layernorm_order',
                             'max_sequence_length', 'inner_hidden_size', 'hidden_size_per_attention_head']
         for name in override_attrs:
             text_attr = getattr(text_args, 'text_' + name, None)
